==> tine20-allinone_2020.03.4.tar.bz2: Sales/js/Sales-lang-ru-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Sales **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 12:21+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Russian (http://www.transifex.com/tine20/tine20/language/ru/)\nLanguage: ru\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "The number you have tried to set is already in use!"
: "Число, которое вы пытались установить, уже используется!"

, "You have to set a customer!"
: ""

, "Unknown Currency Code"
: ""

, "The Currency Code you tried to use is not valid. Please use a valid Currency Code as defined in ISO 4217."
: ""

, "Invoice is cleared already"
: ""

, "The Invoice you tried to edit is cleared already, so no editing is possible anymore!"
: ""

, "Number duplicate"
: ""

, "The number you tried to use has been taken already. Please use another one leave the field blank to take the next free number."
: ""

, "Following Invoices Found"
: ""

, "There is an invoice for the same contract after this one. Please delete the following invoice(s) before deleting this one!"
: ""

, "No Right to alter the Number"
: ""

, "You are not allowed to alter the number afterwards!"
: ""

, "Address as Billing Address in Use"
: ""

, "The Address you tried to delete is used in one or more contract(s) as Billing Address. Please assign another Billing Address to these contracts or change this one and do not delete."
: ""

, "The Invoice you tried to delete is cleared already, so deleting is not possible anymore!"
: ""

, "CLEARED"
: ""

, "INVOICE"
: ""

, "Invoice Timesheet"
: ""

, "My Products"
: "Мои продукты"

, "Products created by me"
: ""

, "My Contracts"
: "Мои контракты"

, "Contracts created by myself"
: "Созданные мной контракты"

, "All Customers"
: ""

, "All customer records"
: ""

, "All Offers"
: ""

, "All offer records"
: ""

, "Inactive Contracts"
: ""

, "Contracts that have already been terminated"
: ""

, "Active Contracts"
: ""

, "Contracts that are still running"
: ""

, "All Suppliers"
: "Все поставщики"

, "All supllier records"
: ""

, "All Purchase Imvoices"
: ""

, "All purchase invoices"
: ""

, "All Products"
: "Все продукты"

, "All product records"
: ""

, "All Contracts"
: "Все контакты"

, "All contract records"
: ""

, "All Invoices"
: ""

, "All invoice records"
: ""

, "All Cost Centers"
: ""

, "All costcenter records"
: ""

, "All Divisions"
: ""

, "All division records"
: ""

, "All Order Confirmations"
: ""

, "All order confirmation records"
: ""

, "manage products"
: "управление продуктами"

, "add, edit and delete products"
: "добавление, изменение и удаление продуктов"

, "manage contracts"
: "управление контрактами"

, "add, edit and delete contracts"
: "добавление, изменение и удаление контактов"

, "manage cost centers"
: ""

, "add, edit and delete cost centers"
: ""

, "manage customers"
: "управление клиентами"

, "add, edit and delete customers"
: "добавление, изменение и удаление клиентов"

, "manage suppliers"
: "управление поставщиками"

, "add, edit and delete suppliers"
: "добавление, изменение и удаление поставщиков"

, "manage invoices"
: "управление счетами"

, "add, edit and delete invoices"
: "добавление, изменение и удаление счетов"

, "manage divisions"
: ""

, "add, edit and delete divisions"
: ""

, "manage order confirmations"
: ""

, "add, edit and delete order confirmations"
: ""

, "manage offers"
: ""

, "add, edit and delete offers"
: ""

, "manage purchase invoices"
: ""

, "add, edit and delete purchase invoices"
: ""

, "change number of an order confirmations"
: ""

, "allow to change the number of an order confirmation on update"
: ""

, "set number of invoices"
: ""

, "allow to set the number of an invoice"
: ""

, "Ok"
: "Ok"

, "Cancel"
: "Отмена"

, "OK"
: "OK"

, "Loading..."
: "Загрузка..."

, "Euro (€)"
: "Евро (€)"

, "Customer, Customers"
: [
  "Клиент"
 ,"Клиента"
 ,"Клиентов"
 ,"Клиенты"

]
, "without customer"
: "без клиента"

, "Number"
: "Число"

, "Remark"
: "Примечание"

, "Delivery Address"
: "Адрес доставки"

, "Delivery Addresses"
: "Адреса доставки"

, "Billing Address"
: "Адрес для выставления счетов"

, "Billing Addresses"
: "Адреса для выставления счетов"

, "total"
: ""

, "inclusive"
: ""

, "exceeding"
: ""

, "Create timesheet"
: ""

, "Create Reversal Invoice"
: ""

, "Copy Invoice"
: "Копировать счёт"

, "Add New Invoice"
: "Добавить новый счёт"

, "Edit Invoice \"{0}\""
: ""

, "Positions ({0})"
: ""

, "No customer assigned"
: "Не указан клиент"

, "The selected contract doesn't have a customer assigned, yet. Add a customer to the contract with the contract edit dialog."
: ""

, "No cost center assigned"
: ""

, "The selected contract doesn't have a cost center assigned, yet. Add a cost center to the contract with the contract edit dialog."
: ""

, "Price Net"
: ""

, "Price Tax"
: ""

, "Price Gross"
: ""

, "Sales Tax (percent)"
: ""

, "Inventory Change"
: ""

, "Invoice, Invoices"
: [
  ""
 ,""
 ,""
 ,""

]
, "Invoice Number"
: "Номер счёта"

, "automatically set..."
: "автоматически установлено..."

, "Date"
: "Дата"

, "Type"
: "Тип"

, "Description"
: "Описание"

, "Contract, Contracts"
: [
  "Договор"
 ,"Договора"
 ,"Договоров"
 ,"Договоров"

]
, "Miscellaneous"
: ""

, "Credit Term"
: "Срок оплаты"

, "Cleared"
: "Просчитано"

, "Interval Begins"
: "Период начинается"

, "Interval Ends"
: "Период заканчивается"

, "Either postalcode or postbox is required!"
: "Необходимо указать почтовый индекс или почтовый ящик!"

, "Copy Supplier"
: "Копировать поставщика"

, "Add New Supplier"
: "Добавить нового поставщика"

, "Edit Supplier \"{0}\""
: "Редактировать поставщика \"{0}\""

, "Copy address to the clipboard"
: "Скопировать адрес в буфер обмена"

, "Supplier, Suppliers"
: [
  ""
 ,""
 ,""
 ,""

]
, "Core Data"
: ""

, "Supplier Number"
: "Номер поставщика"

, "Name"
: "Название"

, "Contact Person (external)"
: "Контактное лицо (внешнее)"

, "Contact Person (internal)"
: "Контактное лицо (внутреннее)"

, "Accounting"
: ""

, "VAT No."
: ""

, "Credit Term (days)"
: "Срок оплаты (дней)"

, "Currency"
: "Валюта"

, "Currency Translation Rate"
: "Курс валюты"

, "IBAN"
: "IBAN"

, "BIC"
: "BIC"

, "Postal Address"
: "Почтовый адрес"

, "Street"
: "Улица"

, "Postbox"
: ""

, "Postalcode"
: "Почтовый индекс"

, "Locality"
: "Местонахождение"

, "Region"
: "Область"

, "Country"
: "Страна"

, "Prefix"
: ""

, "Additional Prefix"
: ""

, "Web"
: "Сайт"

, "Enter description"
: "Введите описание"

, "without supplier"
: "без поставщика"

, "Select supplier"
: "Выбрать поставщика"

, "Select invoice"
: "Выберите счёт"

, "Select customer"
: ""

, "Customer Number"
: "Номер клиента"

, "without internal contact person"
: ""

, "Title"
: "Заголовок"

, "Add New Product"
: "Добавить новый продукт"

, "Product Number"
: ""

, "GTIN"
: ""

, "Category"
: "Категория"

, "Manufacturer"
: "Производитель"

, "Purchaseprice"
: ""

, "Salesprice"
: ""

, "Lifespan start"
: ""

, "Lifespan end"
: ""

, "Enter description..."
: "Ввести описание..."

, "Accountable"
: ""

, "Rebilling Invoice..."
: ""

, "Rebill Invoice"
: ""

, "Merge Invoices"
: ""

, "Add New Cost Center"
: ""

, "Add New Offer"
: "Добавить новое предложение"

, "Total Price"
: "Итоговая цена"

, "Add New Order Confirmation"
: ""

, "Offer, Offers"
: [
  ""
 ,""
 ,""
 ,""

]
, "Products"
: ""

, "Either street or postbox is required!"
: ""

, "Only numbers are allowed!"
: ""

, "Copy Customer"
: ""

, "Add New Customer"
: ""

, "Edit Customer \"{0}\""
: ""

, "Discount (%)"
: "Скидка (%)"

, "Name shorthand"
: ""

, "Set as accountable"
: ""

, "Choose product for accountable"
: ""

, "Please use a decimal number here!"
: "Пожалуйста, используйте десятичные цифры!"

, "Positions"
: ""

, "Start Date"
: "Дата начала"

, "End Date"
: "Дата окончания"

, "Lead Cost Center"
: ""

, "without external contact person"
: "без внешнего контактного лица"

, "Edit {0} \"{1}\""
: "Редактировать {0} \"{1}\""

, "Add new Billing Address"
: ""

, "Add new Delivery Address"
: ""

, "Apply postal address"
: ""

, "Number Debit"
: ""

, "Address, Addresss"
: [
  "Адрес"
 ,"Адреса"
 ,"Адресов"
 ,"Адреса"

]
, "Clipboard"
: "Буфер обмена"

, "Order Confirmation, Order Confirmations"
: [
  ""
 ,""
 ,""
 ,""

]
, "without order confirmation"
: ""

, "Copy Purchase Invoice"
: ""

, "Add New Purchase Invoice"
: ""

, "Edit Purchase Invoice \"{0}\""
: ""

, "Date of invoice"
: "Дата счёта"

, "Due in"
: "Оплата через "

, "Due date"
: "Дата оплаты"

, "Additional Price Gross"
: ""

, "Purchase Invoice, Purchase Invoices"
: [
  ""
 ,""
 ,""
 ,""

]
, "Overdue date"
: "Дата просрочки"

, "Discount until"
: "Скидка до"

, "Dun date"
: ""

, "Payed at"
: "Оплачено"

, "Method of payment"
: "Способ оплаты"

, "Approver"
: ""

, "Bill Contract"
: ""

, "Billing Contract..."
: ""

, "Bill Contract \"{0} - {1}\""
: ""

, "Select the date to generate the bill for"
: ""

, "without Cost Center"
: ""

, "Product, Products"
: [
  "Продукт"
 ,"Продукты"
 ,"Продукты"
 ,"Продукты"

]
, "Quantity"
: "Количество"

, "Interval"
: "Интервал"

, "Billing Point"
: ""

, "begin"
: ""

, "end"
: ""

, "Last Autobill"
: ""

, "Creation Time"
: "Дата создания"

, "Created By"
: "Создано"

, "Last Modified Time"
: "Дата последнего изменения"

, "Last Modified By"
: ""

, "Edit Attributes"
: ""

, "Attribute"
: ""

, "Value"
: ""

, "Add a New Value..."
: ""

, "Add New Division"
: "Добавить новое подразделение"

, "without approver"
: ""

, "Selected  {0}"
: ""

, "Export Records from these Positions"
: ""

, "without contract"
: "без контракта"

, "You do not have admin rights on Sales"
: "У вас нет административных прав на Продажи"

, "Cost Center, Cost Centers"
: [
  ""
 ,""
 ,""
 ,""

]
, "Due at"
: ""

, "Payment_method"
: ""

, "Sales Tax"
: ""

, "Billing Interval"
: ""

, "Invoice Item"
: ""

, "Piece"
: ""

, "Reversal Invoice"
: ""

, "Division, Divisions"
: [
  "Подразделение"
 ,"Подразделения"
 ,"Подразделения"
 ,"Подразделения"

]
, "Invoice Position, Invoice Positions"
: [
  ""
 ,""
 ,""
 ,""

]
, "Month"
: "Месяц"

, "Unit"
: ""

, "Merge"
: ""

, "Responsible"
: "Ответственный"

, "Partner"
: "Партнёр"

, "Time Account"
: "Временный счет"

, "Is active"
: ""

, "Auto Invoice Contract Interval"
: ""

, "Sets the biggest interval, contracts will be billed."
: ""

, "Ignore Billables Before Date"
: ""

, "Sets the date billables will be ignored before."
: ""

, "Contract Number Creation"
: "Создание номера контракта"

, "Should the contract number be set manually or be auto-created?"
: "Задать номер контракта в ручную или создать автоматически?"

, "automatically"
: "автоматически"

, "manually"
: "в ручную"

, "Contract Number Validation"
: "Проверка номера контракта"

, "The Number can be validated as text or number."
: "Номер должен быть проверен как текст или число"

, "Text"
: "Текст"

, "Own Currency"
: ""

, "The currency defined here is used as default currency in the customerd edit dialog."
: ""

, "Invoice Type"
: ""

, "Possible Invoice Types."
: ""

, "Reversal"
: ""

, "Credit"
: "Кредит"

, "Product Category"
: ""

, "Possible Product Categories."
: ""

, "Default"
: "По-умолчанию"

, "Product Number Creation"
: ""

, "Should the product number be set manually or be auto-created?"
: ""

, "Product Number Validation"
: ""

, "Product Number Prefix"
: ""

, "The prefix of the product number."
: ""

, "Product Number Zero Fill"
: ""

, "Fill the number with leading zero"
: ""

, "Payment Method"
: ""

, "Possible Payment Methods."
: ""

, "Bank transfer"
: ""

, "Direct debit"
: ""

, "Cancellation"
: ""

, "Credit card"
: "Кредитная карта"

, "EC card"
: ""

, "Paypal"
: "Paypal"

, "Assets"
: ""

, "Invoice Cleared"
: ""

, "Possible Invoice Cleared States."
: ""

, "to clear"
: "очистить"

, "cleared"
: "очищено"

, "Enabled Features"
: ""

, "Enabled Features in Sales Application."
: ""

, "Invoices Module"
: ""

, "Offers Module"
: ""

, "Order Confirmations Module"
: ""

, "Suppliers Module"
: "Модуль управления поставщиками"

, "Purchase Invoice Module"
: ""



, "Customer"
: "Клиент"

, "Invoice"
: ""

, "Contract"
: "Договор"

, "Supplier"
: ""

, "Offer"
: ""

, "Address"
: "Адрес"

, "Order Confirmation"
: ""

, "Purchase Invoice"
: ""

, "Product"
: "Продукт"

, "Cost Center"
: ""

, "Division"
: "Подразделение"

, "Invoice Position"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.08.8.tar.bz2: Sales/js/Sales-lang-ru-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Sales **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 12:21+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Russian (http://www.transifex.com/tine20/tine20/language/ru/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: ru\nPlural-Forms: nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "CLEARED"
: ""

, "INVOICE"
: ""

, "Invoice Timesheet"
: ""

, "Customer, Customers"
: [
  "Клиент"
 ,"Клиента"
 ,"Клиентов"
 ,"Клиенты"

]
, "Core Data"
: ""

, "Accounting"
: ""

, "Miscellaneous"
: ""

, "Customer Number"
: "Номер клиента"

, "Name"
: "Название"

, "Name shorthand"
: ""

, "Web"
: "Сайт"

, "Description"
: "Описание"

, "Contact Person (external)"
: "Контактное лицо (внешнее)"

, "Contact Person (internal)"
: "Контактное лицо (внутреннее)"

, "VAT No."
: ""

, "Credit Term (days)"
: "Срок оплаты (дней)"

, "Currency"
: "Валюта"

, "Currency Translation Rate"
: "Курс валюты"

, "Discount (%)"
: "Скидка (%)"

, "Delivery Addresses"
: "Адреса доставки"

, "Billing Addresses"
: "Адреса для выставления счетов"

, "Prefix"
: ""

, "Additional Prefix"
: ""

, "Street"
: "Улица"

, "Postalcode"
: "Почтовый индекс"

, "Locality"
: "Местонахождение"

, "Region"
: "Область"

, "Country"
: "Страна"

, "Postbox"
: ""

, "Invoice Position, Invoice Positions"
: [
  ""
 ,""
 ,""
 ,""

]
, "Type"
: "Тип"

, "Title"
: "Заголовок"

, "Month"
: "Месяц"

, "Unit"
: ""

, "Quantity"
: "Количество"

, "Offer, Offers"
: [
  ""
 ,""
 ,""
 ,""

]
, "Order Confirmation, Order Confirmations"
: [
  ""
 ,""
 ,""
 ,""

]
, "Number"
: "Число"

, "Product, Products"
: [
  "Продукт"
 ,"Продукты"
 ,"Продукты"
 ,"Продукты"

]
, "Contract, Contracts"
: [
  "Договор"
 ,"Договора"
 ,"Договоров"
 ,"Договоров"

]
, "Billing Interval"
: ""

, "Billing Point"
: ""

, "Start Date"
: "Дата начала"

, "End Date"
: "Дата окончания"

, "Invoice Item"
: ""

, "Piece"
: ""

, "Purchaseprice"
: ""

, "Salesprice"
: ""

, "Category"
: "Категория"

, "Manufacturer"
: "Производитель"

, "Accountable"
: ""

, "GTIN"
: ""

, "Lifespan start"
: ""

, "Lifespan end"
: ""

, "Is active"
: ""

, "Invoice, Invoices"
: [
  ""
 ,""
 ,""
 ,""

]
, "Invoice Number"
: "Номер счёта"

, "Address, Addresss"
: [
  "Адрес"
 ,"Адреса"
 ,"Адресов"
 ,"Адреса"

]
, "Date"
: "Дата"

, "Interval Begins"
: "Период начинается"

, "Interval Ends"
: "Период заканчивается"

, "Credit Term"
: "Срок оплаты"

, "Cost Center, Cost Centers"
: [
  ""
 ,""
 ,""
 ,""

]
, "Cleared"
: "Просчитано"

, "Price Net"
: ""

, "Price Tax"
: ""

, "Price Gross"
: ""

, "Sales Tax"
: ""

, "Inventory Change"
: ""

, "Positions"
: ""

, "Reversal Invoice"
: ""

, "Supplier, Suppliers"
: [
  ""
 ,""
 ,""
 ,""

]
, "Supplier Number"
: "Номер поставщика"

, "Division, Divisions"
: [
  "Подразделение"
 ,"Подразделения"
 ,"Подразделения"
 ,"Подразделения"

]
, "Number Debit"
: ""

, "Products"
: ""

, "Billing Address"
: "Адрес для выставления счетов"

, "Lead Cost Center"
: ""

, "Merge"
: ""

, "Responsible"
: "Ответственный"

, "Partner"
: "Партнёр"

, "Time Account"
: "Временный счет"

, "Remark"
: "Примечание"

, "Purchase Invoice, Purchase Invoices"
: [
  ""
 ,""
 ,""
 ,""

]
, "Approver"
: ""

, "Date of invoice"
: "Дата счёта"

, "Due in"
: "Оплата через "

, "Due at"
: ""

, "Payed at"
: "Оплачено"

, "Payment_method"
: ""

, "Discount until"
: "Скидка до"

, "Additional Price Gross"
: ""

, "Total Price"
: "Итоговая цена"

, "without customer"
: "без клиента"

, "Export Records from these Positions"
: ""

, "Either postalcode or postbox is required!"
: "Необходимо указать почтовый индекс или почтовый ящик!"

, "Copy Supplier"
: "Копировать поставщика"

, "Add New Supplier"
: "Добавить нового поставщика"

, "Edit Supplier \"{0}\""
: "Редактировать поставщика \"{0}\""

, "Copy address to the clipboard"
: "Скопировать адрес в буфер обмена"

, "IBAN"
: "IBAN"

, "BIC"
: "BIC"

, "Postal Address"
: "Почтовый адрес"

, "Enter description"
: "Введите описание"

, "Cancel"
: "Отмена"

, "Ok"
: "Ok"

, "Select customer"
: ""

, "Bill Contract"
: ""

, "Billing Contract..."
: ""

, "Bill Contract \"{0} - {1}\""
: ""

, "Select the date to generate the bill for"
: ""

, "total"
: ""

, "inclusive"
: ""

, "exceeding"
: ""

, "Create timesheet"
: ""

, "Create Reversal Invoice"
: ""

, "Copy Invoice"
: "Копировать счёт"

, "Add New Invoice"
: "Добавить новый счёт"

, "Edit Invoice \"{0}\""
: ""

, "Positions ({0})"
: ""

, "No customer assigned"
: "Не указан клиент"

, "The selected contract doesn't have a customer assigned, yet. Add a customer to the contract with the contract edit dialog."
: ""

, "No cost center assigned"
: ""

, "The selected contract doesn't have a cost center assigned, yet. Add a cost center to the contract with the contract edit dialog."
: ""

, "Sales Tax (percent)"
: ""

, "automatically set..."
: "автоматически установлено..."

, "OK"
: "OK"

, "Loading..."
: "Загрузка..."

, "Euro (€)"
: "Евро (€)"

, "Set as accountable"
: ""

, "Choose product for accountable"
: ""

, "Please use a decimal number here!"
: "Пожалуйста, используйте десятичные цифры!"

, "Enter description..."
: "Ввести описание..."

, "Add New Product"
: "Добавить новый продукт"

, "Product Number"
: ""

, "Select supplier"
: "Выбрать поставщика"

, "Add New Cost Center"
: ""

, "Select invoice"
: "Выберите счёт"

, "Either street or postbox is required!"
: ""

, "Only numbers are allowed!"
: ""

, "Copy Customer"
: ""

, "Add New Customer"
: ""

, "Edit Customer \"{0}\""
: ""

, "without external contact person"
: "без внешнего контактного лица"

, "without approver"
: ""

, "without supplier"
: "без поставщика"

, "Copy Purchase Invoice"
: ""

, "Add New Purchase Invoice"
: ""

, "Edit Purchase Invoice \"{0}\""
: ""

, "Due date"
: "Дата оплаты"

, "Overdue date"
: "Дата просрочки"

, "Dun date"
: ""

, "Method of payment"
: "Способ оплаты"

, "without internal contact person"
: ""

, "Delivery Address"
: "Адрес доставки"

, "Edit {0} \"{1}\""
: "Редактировать {0} \"{1}\""

, "Add new Billing Address"
: ""

, "Add new Delivery Address"
: ""

, "Apply postal address"
: ""

, "Add New Offer"
: "Добавить новое предложение"

, "Add New Order Confirmation"
: ""

, "Interval"
: "Интервал"

, "begin"
: ""

, "end"
: ""

, "Last Autobill"
: ""

, "Creation Time"
: "Дата создания"

, "Created By"
: "Создано"

, "Last Modified Time"
: "Дата последнего изменения"

, "Last Modified By"
: ""

, "Edit Attributes"
: ""

, "Attribute"
: ""

, "Value"
: ""

, "Add a New Value..."
: ""

, "Clipboard"
: "Буфер обмена"

, "Add New Division"
: "Добавить новое подразделение"

, "without contract"
: "без контракта"

, "without order confirmation"
: ""

, "Rebilling Invoice..."
: ""

, "Rebill Invoice"
: ""

, "Merge Invoices"
: ""

, "without Cost Center"
: ""

, "Auto Invoice Contract Interval"
: ""

, "Sets the biggest interval, contracts will be billed."
: ""

, "Ignore Billables Before Date"
: ""

, "Sets the date billables will be ignored before."
: ""

, "Contract Number Creation"
: "Создание номера контракта"

, "Should the contract number be set manually or be auto-created?"
: "Задать номер контракта в ручную или создать автоматически?"

, "automatically"
: "автоматически"

, "manually"
: "в ручную"

, "Contract Number Validation"
: "Проверка номера контракта"

, "The Number can be validated as text or number."
: "Номер должен быть проверен как текст или число"

, "Text"
: "Текст"

, "Own Currency"
: ""

, "The currency defined here is used as default currency in the customerd edit dialog."
: ""

, "Invoice Type"
: ""

, "Possible Invoice Types."
: ""

, "Reversal"
: ""

, "Credit"
: "Кредит"

, "Product Category"
: ""

, "Possible Product Categories."
: ""

, "Default"
: "По-умолчанию"

, "Product Number Creation"
: ""

, "Should the product number be set manually or be auto-created?"
: ""

, "Product Number Validation"
: ""

, "Product Number Prefix"
: ""

, "The prefix of the product number."
: ""

, "Product Number Zero Fill"
: ""

, "Fill the number with leading zero"
: ""

, "Payment Method"
: ""

, "Possible Payment Methods."
: ""

, "Bank transfer"
: ""

, "Direct debit"
: ""

, "Cancellation"
: ""

, "Credit card"
: "Кредитная карта"

, "EC card"
: ""

, "Paypal"
: "Paypal"

, "Invoice Cleared"
: ""

, "Possible Invoice Cleared States."
: ""

, "to clear"
: "очистить"

, "cleared"
: "очищено"

, "Enabled Features"
: ""

, "Enabled Features in Sales Application."
: ""

, "Invoices Module"
: ""

, "Offers Module"
: ""

, "Order Confirmations Module"
: ""

, "Suppliers Module"
: "Модуль управления поставщиками"

, "Purchase Invoice Module"
: ""

, "manage products"
: "управление продуктами"

, "add, edit and delete products"
: "добавление, изменение и удаление продуктов"

, "manage contracts"
: "управление контрактами"

, "add, edit and delete contracts"
: "добавление, изменение и удаление контактов"

, "manage cost centers"
: ""

, "add, edit and delete cost centers"
: ""

, "manage customers"
: "управление клиентами"

, "add, edit and delete customers"
: "добавление, изменение и удаление клиентов"

, "manage suppliers"
: "управление поставщиками"

, "add, edit and delete suppliers"
: "добавление, изменение и удаление поставщиков"

, "manage invoices"
: "управление счетами"

, "add, edit and delete invoices"
: "добавление, изменение и удаление счетов"

, "manage divisions"
: ""

, "add, edit and delete divisions"
: ""

, "manage order confirmations"
: ""

, "add, edit and delete order confirmations"
: ""

, "manage offers"
: ""

, "add, edit and delete offers"
: ""

, "manage purchase invoices"
: ""

, "add, edit and delete purchase invoices"
: ""

, "change number of an order confirmations"
: ""

, "allow to change the number of an order confirmation on update"
: ""

, "set number of invoices"
: ""

, "allow to set the number of an invoice"
: ""

, "No Right to alter the Number"
: ""

, "You are not allowed to alter the number afterwards!"
: ""

, "Address as Billing Address in Use"
: ""

, "The Address you tried to delete is used in one or more contract(s) as Billing Address. Please assign another Billing Address to these contracts or change this one and do not delete."
: ""

, "Number duplicate"
: ""

, "The number you tried to use has been taken already. Please use another one leave the field blank to take the next free number."
: ""

, "Following Invoices Found"
: ""

, "There is an invoice for the same contract after this one. Please delete the following invoice(s) before deleting this one!"
: ""

, "Invoice is cleared already"
: ""

, "The Invoice you tried to edit is cleared already, so no editing is possible anymore!"
: ""

, "The Invoice you tried to delete is cleared already, so deleting is not possible anymore!"
: ""

, "Unknown Currency Code"
: ""

, "The Currency Code you tried to use is not valid. Please use a valid Currency Code as defined in ISO 4217."
: ""

, "You do not have admin rights on Sales"
: "У вас нет административных прав на Продажи"

, "The number you have tried to set is already in use!"
: "Число, которое вы пытались установить, уже используется!"

, "My Products"
: "Мои продукты"

, "Products created by me"
: ""

, "My Contracts"
: "Мои контракты"

, "Contracts created by myself"
: "Созданные мной контракты"

, "All Customers"
: ""

, "All customer records"
: ""

, "All Offers"
: ""

, "All offer records"
: ""

, "Inactive Contracts"
: ""

, "Contracts that have already been terminated"
: ""

, "Active Contracts"
: ""

, "Contracts that are still running"
: ""

, "Products created by myself"
: "Созданные мной продукты"

, "Status"
: "Статус"

, "Cleared In"
: ""

, "All Suppliers"
: "Все поставщики"

, "All supllier records"
: ""

, "All Purchase Imvoices"
: ""

, "All purchase invoices"
: ""

, "All Products"
: "Все продукты"

, "All product records"
: ""

, "All Contracts"
: "Все контакты"

, "All contract records"
: ""

, "All Invoices"
: ""

, "All invoice records"
: ""

, "All Cost Centers"
: ""

, "All costcenter records"
: ""

, "All Divisions"
: ""

, "All division records"
: ""

, "All Order Confirmations"
: ""

, "All order confirmation records"
: ""

, "You have to set a customer!"
: ""

, "Taxes (VAT)"
: ""

, "VAT ID"
: ""

, "Selected  {0}"
: ""

, "Add New Billing Address"
: ""

, "Add New Delivery Address"
: ""

, "Manage Products"
: ""

, "Add, edit and delete products."
: ""

, "Manage Contracts"
: ""

, "Add, edit and delete contracts."
: ""

, "Manage Cost Centers"
: ""

, "Add, edit and delete cost centers."
: ""

, "Manage Customers"
: ""

, "Add, edit and delete customers."
: ""

, "Manage Suppliers"
: ""

, "Add, edit and delete suppliers."
: ""

, "Add, edit and delete invoices."
: ""

, "Manage Divisions"
: ""

, "Add, edit and delete divisions."
: ""

, "Manage Order Confirmations"
: ""

, "Add, edit and delete order confirmations."
: ""

, "Manage Offers"
: ""

, "Add, edit and delete offers."
: ""

, "Manage Purchase Invoices"
: ""

, "Add, edit and delete purchase invoices."
: ""

, "Change number of an order confirmations"
: ""

, "Allow changing the number of an order confirmation during the update."
: ""

, "Set number of invoices"
: ""

, "Allow to set the number of an invoice."
: ""

, "Customer"
: "Клиент"

, "Invoice Position"
: ""

, "Offer"
: ""

, "Order Confirmation"
: ""

, "Product"
: "Продукт"

, "Contract"
: "Договор"

, "Invoice"
: ""

, "Address"
: "Адрес"

, "Cost Center"
: ""

, "Supplier"
: ""

, "Division"
: "Подразделение"

, "Purchase Invoice"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
